@@ -1,25 +1,25 @@
 # These are unexported functions that are called by the C routines of the tikz
 # device to execute tasks that are difficult to do at the C level.
 
-getDateStampForTikz <- function(){
+getDateStampForTikz <- function() {
 
   # This function retrieves the current date stamp using
   # sys.time() and formats it to a string. This function
   # is used by the C routine Print_TikZ_Header to add
   # date stamps to output files.
 
-  return( strftime( Sys.time() ) )
-
+  return(strftime(Sys.time()))
 }
 
 getTikzDeviceVersion <- function() {
-  as.character(packageVersion('tikzDevice'))
+  as.character(packageVersion("tikzDevice"))
 }
 
 tikz_writeRaster <- function(fileName, rasterCount, nativeRaster) {
   raster_file <- paste0(
     tools::file_path_sans_ext(fileName),
-    '_ras', rasterCount, '.png')
+    "_ras", rasterCount, ".png"
+  )
 
   png::writePNG(nativeRaster, raster_file)
 
